/******************************************************************
*
*	CyberUPnP for Java
*
*	Copyright (C) Satoshi Konno 2002
*
*	File: MediaServer.java
*
*	Revision;
*
*	12/13/02
*		- first revision.
*
******************************************************************/

//package org.cybergarage.media.server;

import java.io.*;

import org.cybergarage.upnp.*;
import org.cybergarage.http.*;
import org.cybergarage.util.*;

public class MediaServer implements HTTPRequestListener
{
	////////////////////////////////////////////////
	//	Constants
	////////////////////////////////////////////////

	public final static int SERVICE_PORT = 4004;
	public final static String NAME = "CyberGarage UPnP Server";
	public final static String VERSION = "1.0";
	
	////////////////////////////////////////////////
	//	Constructor
	////////////////////////////////////////////////
	
	public MediaServer()
	{
		initDevice(SERVICE_PORT);
	}

	////////////////////////////////////////////////
	//	Constructor
	////////////////////////////////////////////////

	private Device upnpDev = null;
		
	public void initDevice(int port)
	{
		upnpDev = new Device();
		//upnpDev.setPort(port);
		//upnpDev.addHTTPRequestListener(this);
	}

	public Device getDevice()
	{
		return upnpDev;
	}

	////////////////////////////////////////////////
	//	start/stop
	////////////////////////////////////////////////
	
	public void start()
	{
		getDevice().start();
	}

	public void stop()
	{
		getDevice().stop();
	}
	
	////////////////////////////////////////////////
	//	HTTP Request
	////////////////////////////////////////////////
	
	public void httpRequestRecieved(HTTPRequest httpReq)
	{
		Debug.message("httpReq = " + httpReq);
		Debug.message(" METHOD = " + httpReq.getMethod());
		Debug.message(" URI = " + httpReq.getURI());

		HTTPSocket httpSock = httpReq.getSocket();		
		
		HTTPResponse httpRes = new HTTPResponse();
		httpRes.setStatusCode(HTTPStatus.OK);
		//String filename = "movie/sample.mov"; // - QuickTime OK
		//String filename = "movie/sample.mpg"; //- MPEG1 OK
		//String filename = "movie/sample.asf"; // - Microsoft MPEG4 X
		//String filename = "movie/sample.avi"; // DivX MPEG4 - OK;
		//String filename = "movie/sample.mpeg"; // MPEG2 - X
		String filename = "movie/sample_mpeg2.avi"; // MPEG2 - X		
		byte fileBin[] = loadFile(filename); // - X
		Debug.message(" flie = " + filename + " (" + fileBin.length + " bytes)");
		if (0 < fileBin.length) {
			//httpRes.setContentType("video/quicktime");
			//httpRes.setContentType("video/mpeg");
			httpRes.setContentType("*/*");
			httpRes.setContent(fileBin);
		}
		httpSock.post(httpRes);
	}
	
	private byte[] loadFile(String fileName)
	{
		byte readBuf[] = new byte[1024];
	
		try {	
			FileInputStream fin=new FileInputStream(fileName);
			ByteArrayOutputStream bout = new ByteArrayOutputStream();
		
			int readCnt = fin.read(readBuf);
			while (0 < readCnt) {
				bout.write(readBuf, 0, readCnt);
				readCnt = fin.read(readBuf);
			}
			
			fin.close();
			
			return bout.toByteArray();
		}
		catch (Exception e) {
			Debug.warning(e);
			return new byte[0];
		}
	}
	
	////////////////////////////////////////////////
	//	main
	////////////////////////////////////////////////

	public static void main(String args[]) 
	{
		Debug.on();
		
		MediaServer server = new MediaServer();
		server.start();
		
		//System.exit(0);
	}
}

